@@ -1,25 +1,25 @@
-/* 
+/*
  * Mach Operating System
  * Copyright (c) 1991,1990,1989,1988 Carnegie Mellon University
  * All Rights Reserved.
- * 
+ *
  * Permission to use, copy, modify and distribute this software and its
  * documentation is hereby granted, provided that both the copyright
  * notice and this permission notice appear in all copies of the
  * software, derivative works or modified versions, and any portions
  * thereof, and that both notices appear in supporting documentation.
- * 
+ *
  * CARNEGIE MELLON ALLOWS FREE USE OF THIS SOFTWARE IN ITS "AS IS"
  * CONDITION.  CARNEGIE MELLON DISCLAIMS ANY LIABILITY OF ANY KIND FOR
  * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
- * 
+ *
  * Carnegie Mellon requests users of this software to return to
- * 
+ *
  *  Software Distribution Coordinator  or  Software.Distribution@CS.CMU.EDU
  *  School of Computer Science
  *  Carnegie Mellon University
  *  Pittsburgh PA 15213-3890
- * 
+ *
  * any improvements or extensions that they make and grant Carnegie Mellon
  * the rights to redistribute these changes.
  */
@@ -77,12 +77,12 @@ thread_kdb_return()
 		/*NOTREACHED*/
 	}
 }
-#endif	MACH_KDB
+#endif	/* MACH_KDB */
 
 #if	MACH_TTD
 extern boolean_t kttd_enabled;
 boolean_t debug_all_traps_with_kttd = TRUE;
-#endif	MACH_TTD
+#endif	/* MACH_TTD */
 
 void
 user_page_fault_continue(kr)
@@ -100,7 +100,7 @@ user_page_fault_continue(kr)
 				       (vm_offset_t)regs->cr2,
 				       regs))
 			kdb_trap(T_WATCHPOINT, 0, regs);
-#endif	MACH_KDB
+#endif	/* MACH_KDB */
 		thread_exception_return();
 		/*NOTREACHED*/
 	}
@@ -111,7 +111,7 @@ user_page_fault_continue(kr)
 		thread_exception_return();
 		/*NOTREACHED*/
 	}
-#endif	MACH_KDB
+#endif	/* MACH_KDB */
 
 	i386_exception(EXC_BAD_ACCESS, kr, regs->cr2);
 	/*NOTREACHED*/
@@ -181,7 +181,7 @@ void kernel_trap(regs)
 	vm_map_t	map;
 	kern_return_t	result;
 	register thread_t	thread;
-	extern char start[], etext[];
+	extern char _start[], etext[];
 
 	type = regs->trapno;
 	code = regs->err;
@@ -231,7 +231,7 @@ dump_ss(regs);
 		printf("now %08x\n", subcode);
 #endif
 			if (trunc_page(subcode) == 0
-			    || (subcode >= (int)start
+			    || (subcode >= (int)_start
 				&& subcode < (int)etext)) {
 				printf("Kernel page fault at address 0x%x, "
 				       "eip = 0x%x\n",
@@ -271,7 +271,7 @@ dump_ss(regs);
 			kdb_trap(T_WATCHPOINT, 0, regs);
 		}
 		else
-#endif	MACH_KDB
+#endif	/* MACH_KDB */
 		if ((code & T_PF_WRITE) == 0 &&
 		    result == KERN_PROTECTION_FAILURE)
 		{
@@ -348,7 +348,7 @@ dump_ss(regs);
 #if	MACH_KDB
 		if (kdb_trap(type, code, regs))
 		    return;
-#endif	MACH_KDB
+#endif	/* MACH_KDB */
 		splhigh();
 		printf("kernel trap, type %d, code = %x\n",
 			type, code);
@@ -527,7 +527,7 @@ printf("user trap %d error %d sub %08x\n", type, code, subcode);
 #if 0
 		printf("user page fault at linear address %08x\n", subcode);
 		dump_ss (regs);
-		
+
 #endif
 		assert(subcode < LINEAR_MIN_KERNEL_ADDRESS);
 		subcode = regs->cr2;
@@ -554,7 +554,7 @@ printf("user trap %d error %d sub %08x\n", type, code, subcode);
 #if	MACH_KDB
 		if (kdb_trap(type, regs->err, regs))
 		    return 0;
-#endif	MACH_KDB
+#endif	/* MACH_KDB */
 		splhigh();
 		printf("user trap, type %d, code = %x\n",
 		       type, regs->err);
@@ -571,7 +571,7 @@ printf("user trap %d error %d sub %08x\n", type, code, subcode);
 	if (debug_all_traps_with_kdb &&
 	    kdb_trap(type, regs->err, regs))
 		return 0;
-#endif	MACH_KDB
+#endif	/* MACH_KDB */
 
 	i386_exception(exc, code, subcode);
 	/*NOTREACHED*/
@@ -1138,4 +1138,3 @@ interrupted_pc(t)
  	return iss->eip;
 }
 #endif	/* MACH_PCSAMPLE > 0*/
-
