@@ -1,25 +1,25 @@
-/* 
+/*
  * Mach Operating System
  * Copyright (c) 1991,1990,1989 Carnegie Mellon University
  * All Rights Reserved.
- * 
+ *
  * Permission to use, copy, modify and distribute this software and its
  * documentation is hereby granted, provided that both the copyright
  * notice and this permission notice appear in all copies of the
  * software, derivative works or modified versions, and any portions
  * thereof, and that both notices appear in supporting documentation.
- * 
+ *
  * CARNEGIE MELLON ALLOWS FREE USE OF THIS SOFTWARE IN ITS "AS IS"
  * CONDITION.  CARNEGIE MELLON DISCLAIMS ANY LIABILITY OF ANY KIND FOR
  * ANY DAMAGES WHATSOEVER RESULTING FROM THE USE OF THIS SOFTWARE.
- * 
+ *
  * Carnegie Mellon requests users of this software to return to
- * 
+ *
  *  Software Distribution Coordinator  or  Software.Distribution@CS.CMU.EDU
  *  School of Computer Science
  *  Carnegie Mellon University
  *  Pittsburgh PA 15213-3890
- * 
+ *
  * any improvements or extensions that they make and grant Carnegie Mellon
  * the rights to redistribute these changes.
  */
@@ -247,7 +247,6 @@ ipc_object_alloc(
 
 		bzero((char *)pset, sizeof(*pset));
 	}
-	*namep = (mach_port_t)object;
 	kr = ipc_entry_alloc(space, namep, &entry);
 	if (kr != KERN_SUCCESS) {
 		io_free(otype, object);
@@ -373,7 +372,7 @@ ipc_object_copyin_type(
 
 	    case MSG_TYPE_PORT_ALL:
 		return MACH_MSG_TYPE_PORT_RECEIVE;
-#endif	MACH_IPC_COMPAT
+#endif	/* MACH_IPC_COMPAT */
 
 	    default:
 #if MACH_ASSERT
@@ -727,7 +726,7 @@ ipc_object_copyout_multiname(space, object, namep)
 		*namep = name;
 	return kr;
 }
-#endif 0
+#endif /* 0 */
 
 /*
  *	Routine:	ipc_object_copyout_name
@@ -1279,7 +1278,7 @@ ipc_object_copyout_name_compat(space, object, msgt_name, name)
 	return kr;
 }
 
-#endif	MACH_IPC_COMPAT
+#endif	/* MACH_IPC_COMPAT */
 
 #include <mach_kdb.h>
 
